@@ -203,6 +203,9 @@ void create_tables()
     exec_query(
             "insert into wiki(id, name, content, registerdate) values (NULL, 'help', '"
             "*逆引きヘルプ\n"
+            "**チケットを更新する方法は？\n"
+            "チケットに対して更新を行なうアクションは、チケットの新規登録と、チケットに対する返信のみです。 \n"
+
             "**チケットを新規に作成するには？\n"
             "ナビゲーションメニューの「チケット登録」をクリックしチケット登録ページに移動します。 フォームの各フィールドに値を入力して「登録」ボタンを押すことで新規にチケットを作成することができます。 \n"
 
@@ -215,6 +218,14 @@ void create_tables()
             "**IDを指定してチケットの情報を見るには？\n"
             "ナビゲーションメニューの「チケット登録」をクリックしチケット登録ページに移動します。「IDを指定で表示」ボタンの左のテキストボックスに、チケットIDを入力し、「IDを指定で表示」ボタンを押すことで、チケット詳細ページに移動します。 また、同様の「IDを指定で表示」ボタンは、トップページ、状態別チケット一覧ページにもあります。 \n"
 
+            "**チケットの項目をカスタマイズするには？\n"
+            "ナビゲーションメニューの「管理ツール」をクリックし管理ツールを開き、メニューの「項目設定」をクリックし、項目設定ページに移動します。\n"
+            "各項目の追加、削除、編集を行なうことができます。\n"
+
+            "**チケットの項目に添付資料(ファイル)を追加するには？\n"
+            "ナビゲーションメニューの「管理ツール」をクリックし管理ツールを開き、メニューの「項目設定」をクリックし、項目設定ページに移動します。\n"
+            "「新規項目を追加」リンクをクリックし、項目種別でファイルを選択して項目を追加してください。\n"
+
             "**ある状態で進捗のないチケットを調べたい\n"
             "チケット検索ページか状態別チケット一覧ページで、最終更新日時から現在までの日数を放置日数として表示しています。\n"
             "放置日数を確認してください。\n"
